use dbfile::{DBfile};
use dbfile_derive::{DBfile, dbnote};


#[derive(DBfile)]
#[dbnote(table_name = "test1.csv")]
struct Person<'a>{
    name: &'a str,
    age: u32,
}


pub fn run_write_csv() {
    let p1 = Person {
       name: "zhangsan",
       age: 25,
    };

    let p2 = Person {
        name: "lisi",
        age: 32
    };

    let p3 = Person {
        name: "wangwu",
        age: 33
    };
    
    p1.write_csv_head();
    p1.to_csv("a");
    p2.to_csv("a");
    p3.to_csv("a");
}